import { TextWriter } from "./text-writer";
/**
 * The abstract base class for all code writers. This writer implements the TextWriter interface by decorating
 * the TextWriter provided in the constructor.
 */
export declare abstract class CodeWriter implements TextWriter {
    private writer;
    /**
    * Gets or sets the end of line string. The default value is platform dependent.
    */
    endOfLineString: string;
    /**
     * Gets or sets the indent string. The default value is a '\t' (tab character).
    */
    indentString: string;
    /**
     * Constructor. Creates a new CodeWriter that uses the provided TextWriter internally.
     * @param writer A TextWriter object. In a code generation template, a TextWriter instance can be obtained by calling any of the generate...()
     * functions on the current CodeGenerator.
     */
    constructor(writer: TextWriter);
    /******************************************************************************
     *                          TextWriter delegation
    ******************************************************************************/
    /**
     * Writes a string value to the output.
     * @param value The string value to be written.
     */
    write(value: string): void;
    /**
    * Writes a single whitespace character to the output.
    */
    writeWhiteSpace(): void;
    /**
    * Writes a new line to the output. The line is indented automatically. The line is ended with the endOfLineString.
    * @param value The line to write. When omitted, only the endOfLineString is written.
    */
    writeLine(value?: string): void;
    /**
   * Writes a collection of lines to the output. Each line is indented automatically and ended with the endOfLineString.
   * @param values The lines to write.
   * @param delimiter An optional delimiter to be written at the end of each line, except for the last one.
   */
    writeLines(values: string[], delimiter?: string): void;
    /**
     * Writes a new line to the output while temporarily increasing the indent. The line is ended with the endOfLineString.
     * @param value The line to write.
     */
    writeLineIndented(value: string): void;
    /**
     * Writes the endOfLineString to the output.
     * @param value Any value to write before the endOfLineString string is written.
     */
    writeEndOfLine(value?: string): void;
    /**
      * Writes the contents of the specified file to the output.
      * @param fileName The path of the file, relative to the template.
      * @param encoding Optional: the encoding that is used for the file. The default is 'utf-8'.
      */
    writeFile(path: string, encoding?: string): void;
    /**
    * Writes the contents of the specified file region to the output.
    * @param regionName The name of the region to write. The region should be marked using "/// <region>code goes here...</region>".
    * @param fileName The path of the file, relative to the template.
    * @param encoding The encoding that is used for the file. The default is 'utf-8'.
    */
    writeFileRegion(regionName: string, path: string, encoding?: string): boolean;
    /**
    * Writes the current indentString to the output.
    */
    writeIndent(): void;
    /**
    * Increases the current indent, which is prefixed to each line of the output.
    */
    increaseIndent(): void;
    /**
    * Decreases the current indent, which is prefixed to each line of the output.
    */
    decreaseIndent(): void;
    /**
     * Resets any indentation, causing new line writes to start at the first character position.
     */
    clearIndent(): void;
}
